@@ -35,6 +35,8 @@
  */
 package net.sourceforge.plantuml.klimt.drawing.svg;
 
+import static net.sourceforge.plantuml.klimt.color.HColor.TransparentFillBehavior.WITH_FILL_NONE;
+
 import java.awt.geom.PathIterator;
 import java.awt.image.BufferedImage;
 import java.io.ByteArrayOutputStream;
@@ -60,17 +62,18 @@ import javax.xml.transform.TransformerException;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 
-import net.sourceforge.plantuml.klimt.color.HColor.TransparentFillBehavior;
 import org.w3c.dom.CDATASection;
 import org.w3c.dom.Comment;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
+import org.w3c.dom.ProcessingInstruction;
 
 import net.sourceforge.plantuml.FileUtils;
 import net.sourceforge.plantuml.code.TranscoderUtil;
 import net.sourceforge.plantuml.klimt.UGroupType;
 import net.sourceforge.plantuml.klimt.UPath;
 import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColor.TransparentFillBehavior;
 import net.sourceforge.plantuml.klimt.color.HColorGradient;
 import net.sourceforge.plantuml.klimt.geom.USegment;
 import net.sourceforge.plantuml.klimt.geom.USegmentType;
@@ -80,13 +83,11 @@ import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.security.SImageIO;
 import net.sourceforge.plantuml.security.SecurityProfile;
 import net.sourceforge.plantuml.security.SecurityUtils;
-import net.sourceforge.plantuml.skin.PragmaKey;
 import net.sourceforge.plantuml.utils.Base64Coder;
 import net.sourceforge.plantuml.utils.Log;
+import net.sourceforge.plantuml.version.Version;
 import net.sourceforge.plantuml.xml.XmlFactories;
 
-import static net.sourceforge.plantuml.klimt.color.HColor.TransparentFillBehavior.WITH_FILL_NONE;
-
 public class SvgGraphics {
 	// ::remove file when __HAXE__
 
@@ -311,6 +312,9 @@ public class SvgGraphics {
 	// This method returns a reference to a root node that
 	// has already been appended to the document.
 	private Element getRootNode() {
+		// Add PlantUML version as processing instruction
+		document.appendChild(document.createProcessingInstruction("plantuml", Version.versionString()));
+
 		// Create the root node named svg and append it to
 		// the document.
 		final Element svg = document.createElement("svg");
@@ -555,6 +559,13 @@ public class SvgGraphics {
 	public void text(String text, double x, double y, String fontFamily, int fontSize, String fontWeight,
 			String fontStyle, String textDecoration, double textLength, Map<String, String> attributes,
 			String textBackColor) {
+		text(text, x, y, fontFamily, fontSize, fontWeight, fontStyle, textDecoration, textLength, attributes,
+				textBackColor, 0);
+	}
+
+	public void text(String text, double x, double y, String fontFamily, int fontSize, String fontWeight,
+			String fontStyle, String textDecoration, double textLength, Map<String, String> attributes,
+			String textBackColor, int orientation) {
 		if (hidden == false) {
 			final Element elt = document.createElement("text");
 			// required for web-kit based browsers
@@ -562,6 +573,13 @@ public class SvgGraphics {
 			elt.setAttribute("x", format(x));
 			elt.setAttribute("y", format(y));
 			fillMe(elt);
+
+			// Add rotation if needed
+			if (orientation == 90) {
+				elt.setAttribute("transform", "rotate(-90 " + format(x) + " " + format(y) + ")");
+			} else if (orientation == 270) {
+				elt.setAttribute("transform", "rotate(90 " + format(x) + " " + format(y) + ")");
+			}
 			elt.setAttribute("font-size", format(fontSize));
 			// elt.setAttribute("text-anchor", "middle");
 
@@ -1045,12 +1063,10 @@ public class SvgGraphics {
 	// ::done
 
 	public void addCommentMetadata(String metadata) {
-		// ::comment when __CORE__
-		final String signature = getMetadataHex(metadata).replace("--", "- -");
-		final String comment = "SRC=[" + signature + "]";
-		final Comment commentElement = document.createComment(comment);
-		getG().appendChild(commentElement);
-		// ::done
+		// https://github.com/plantuml/plantuml/issues/2306
+		final String signature = getMetadataHex(metadata);
+		final ProcessingInstruction processingInstruction = document.createProcessingInstruction("plantuml-src", signature);
+		getG().appendChild(processingInstruction);
 	}
 
 	public void addComment(String comment) {
@@ -1213,77 +1229,43 @@ public class SvgGraphics {
 
 		pendingElements.add(0, document.createElement("g"));
 
-		// Sorry for the code duplication: but this Pragma will be removed
-		// So we will simplify and refactor the code at that time.
-		if (option.pragma.isTrue(PragmaKey.SVGNEWDATA)) {
-
-			for (Map.Entry<UGroupType, String> typeIdent : typeIdents.entrySet()) {
-				if (typeIdent.getKey() == UGroupType.TITLE) {
-					Element title = document.createElement(UGroupType.TITLE.getSvgKeyAttributeName());
-					title.setTextContent(typeIdent.getValue());
-					pendingElements.get(0).appendChild(title);
-				}
-
-				switch (typeIdent.getKey()) {
-				case ID:
-					// ignored
-					break;
-				case DATA_UID:
-					// DATA_UID *will* be rename to ID, but right now, we do some hack
-					pendingElements.get(0).setAttribute("id", typeIdent.getValue());
-					break;
-
-				// I also suggest that we rename "data-participant-1" to "data-entity-1" and
-				// "data-participant-2" to "data-entity-2"
-
-				case DATA_PARTICIPANT_1:
-				case DATA_ENTITY_1_UID:
-					pendingElements.get(0).setAttribute("data-entity-1", typeIdent.getValue());
-					break;
-				case DATA_PARTICIPANT_2:
-				case DATA_ENTITY_2_UID:
-					pendingElements.get(0).setAttribute("data-entity-2", typeIdent.getValue());
-					break;
-
-				case CLASS:
-				case DATA_SOURCE_LINE:
-				case DATA_QUALIFIED_NAME:
-				case DATA_ENTITY_UID:
-					pendingElements.get(0).setAttribute(typeIdent.getKey().getSvgKeyAttributeName(),
-							typeIdent.getValue());
-
-				}
-			}
-		} else {
-			for (Map.Entry<UGroupType, String> typeIdent : typeIdents.entrySet()) {
-				if (typeIdent.getKey() == UGroupType.TITLE) {
-					Element title = document.createElement(UGroupType.TITLE.getSvgKeyAttributeName());
-					title.setTextContent(typeIdent.getValue());
-					pendingElements.get(0).appendChild(title);
-				}
-
-				switch (typeIdent.getKey()) {
-				case DATA_UID:
-				case ID:
-				case DATA_SOURCE_LINE:
-					pendingElements.get(0).setAttribute(typeIdent.getKey().getSvgKeyAttributeName(),
-							typeIdent.getValue());
-				}
-
-				// if (option.isInteractive())
-				switch (typeIdent.getKey()) {
-				case CLASS:
-				case DATA_ENTITY:
-				case DATA_ENTITY_1:
-				case DATA_ENTITY_2:
-				case DATA_PARTICIPANT:
-				case DATA_PARTICIPANT_1:
-				case DATA_PARTICIPANT_2:
-					pendingElements.get(0).setAttribute(typeIdent.getKey().getSvgKeyAttributeName(),
-							typeIdent.getValue());
-				}
+		for (Map.Entry<UGroupType, String> typeIdent : typeIdents.entrySet()) {
+			if (typeIdent.getKey() == UGroupType.TITLE) {
+				Element title = document.createElement(UGroupType.TITLE.getSvgKeyAttributeName());
+				title.setTextContent(typeIdent.getValue());
+				pendingElements.get(0).appendChild(title);
 			}
 
+			switch (typeIdent.getKey()) {
+			case ID:
+				// ignored
+				break;
+			case DATA_UID:
+				// DATA_UID *will* be rename to ID, but right now, we do some hack
+				pendingElements.get(0).setAttribute("id", typeIdent.getValue());
+				break;
+
+			// I also suggest that we rename "data-participant-1" to "data-entity-1" and
+			// "data-participant-2" to "data-entity-2"
+
+			case DATA_PARTICIPANT_1:
+			case DATA_ENTITY_1_UID:
+				pendingElements.get(0).setAttribute("data-entity-1", typeIdent.getValue());
+				break;
+			case DATA_PARTICIPANT_2:
+			case DATA_ENTITY_2_UID:
+				pendingElements.get(0).setAttribute("data-entity-2", typeIdent.getValue());
+				break;
+
+			case CLASS:
+			case DATA_SOURCE_LINE:
+			case DATA_QUALIFIED_NAME:
+			case DATA_ENTITY_UID:
+			case DATA_VISIBILITY_MODIFIER:
+			case DATA_LINK_TYPE:
+				pendingElements.get(0).setAttribute(typeIdent.getKey().getSvgKeyAttributeName(), typeIdent.getValue());
+
+			}
 		}
 
 		// Restore link state after group creation if needed
