@@ -44,6 +44,7 @@ import net.sourceforge.plantuml.klimt.creole.SheetBuilder;
 import net.sourceforge.plantuml.klimt.creole.legacy.CreoleParser;
 import net.sourceforge.plantuml.klimt.font.FontConfiguration;
 import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.nio.PathSystem;
 import net.sourceforge.plantuml.preproc.ConfigurationStore;
 import net.sourceforge.plantuml.preproc.OptionKey;
 import net.sourceforge.plantuml.skin.Pragma;
@@ -134,5 +135,10 @@ public class SpriteContainerEmpty implements SpriteContainer, ISkinSimple {
 		return ConfigurationStore.createEmpty();
 	}
 
+	@Override
+	public PathSystem getPathSystem() {
+		return PathSystem.fetch();
+	}
+
 
 }
\ No newline at end of file
