@@ -59,8 +59,8 @@ public class CommandMindMapPlus extends SingleLineCommand2<MindMapDiagram> {
 				new RegexLeaf(1, "TYPE", "([+-]+)"), //
 				new RegexOptional(new RegexLeaf(1, "BACKCOLOR", "\\[(#\\w+)\\]")), //
 				new RegexLeaf(1, "SHAPE", "(_)?"), //
-				RegexLeaf.spaceOneOrMore(), //
-				new RegexLeaf(1, "LABEL", "([^%s].*)"), RegexLeaf.end());
+				RegexLeaf.spaceZeroOrMore(), //
+				new RegexLeaf(1, "LABEL", "(.*)"), RegexLeaf.end());
 	}
 
 	@Override
