@@ -54,8 +54,8 @@ public class CommandMindMapRoot extends SingleLineCommand2<MindMapDiagram> {
 	static IRegex getRegexConcat() {
 		return RegexConcat.build(CommandMindMapRoot.class.getName(), RegexLeaf.start(), //
 				new RegexLeaf(1, "TYPE", "(0)"), //
-				RegexLeaf.spaceOneOrMore(), //
-				new RegexLeaf(1, "LABEL", "([^%s].*)"), RegexLeaf.end());
+				RegexLeaf.spaceZeroOrMore(), //
+				new RegexLeaf(1, "LABEL", "(.*)"), RegexLeaf.end());
 	}
 
 	@Override
